/*
 *  Copyright (C) 2015  Malte Humann
 *
 *  This file is part of the Time Series Anomaly Detection (TSAD).
 *
 *  TSAD is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TSAD is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with TSAD.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.tzi.imonitor;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Utility class providing simplified access to the the {@code tsad.properties}
 * file.
 */
public class Configuration {
	private static Properties properties = new Properties();
	static {
		Logger logger = LoggerFactory.getLogger(Configuration.class);
		try (InputStream stream = ClassLoader
				.getSystemResourceAsStream("tsad.properties")) {
			if (stream != null) {
				properties.load(stream);
			} else {
				logger.error("Configuration file 'tsad.properties' not found.");
			}
		} catch (IOException e) {
			logger.error("Unable to load configuration file: " + e.getMessage());
		}
	}

	/**
	 * Searches for the property specified by the key parameter. If no such
	 * property is available null is returned instead the corresponding property
	 * value.
	 * 
	 * @param key
	 *            the property key
	 * @return the value associated with the given property key or null
	 */
	public static String getProperty(String key) {
		return properties.getProperty(key);
	}
}

